0.9.9 API documentation: GLM_GTX_spline

| 0.9.9 API documentation

- Main Page
- Modules
- Files

Functions
GLM_GTX_spline
Experimental extensions

Include <glm/gtx/spline.hpp> to use the features of this extension. More...

## Functions
template<typename genType >
GLM_FUNC_DECL genType | catmullRom (genType const &v1, genType const &v2, genType const &v3, genType const &v4, typename genType::value_type const &s)
| Return a point from a catmull rom curve. More...
template<typename genType >
GLM_FUNC_DECL genType | cubic (genType const &v1, genType const &v2, genType const &v3, genType const &v4, typename genType::value_type const &s)
| Return a point from a cubic curve. More...
template<typename genType >
GLM_FUNC_DECL genType | hermite (genType const &v1, genType const &t1, genType const &v2, genType const &t2, typename genType::value_type const &s)
| Return a point from a hermite curve. More...

## Detailed Description

Include <glm/gtx/spline.hpp> to use the features of this extension.

Spline functions

## Function Documentation

GLM_FUNC_DECL genType glm::catmullRom | ( | genType const & | v1,
|  | genType const & | v2,
|  | genType const & | v3,
|  | genType const & | v4,
|  | typename genType::value_type const & | s
| ) |  |

Return a point from a catmull rom curve.

See also
  GLM_GTX_spline extension.

GLM_FUNC_DECL genType glm::cubic | ( | genType const & | v1,
|  | genType const & | v2,
|  | genType const & | v3,
|  | genType const & | v4,
|  | typename genType::value_type const & | s
| ) |  |

Return a point from a cubic curve.

See also
  GLM_GTX_spline extension.

GLM_FUNC_DECL genType glm::hermite | ( | genType const & | v1,
|  | genType const & | t1,
|  | genType const & | v2,
|  | genType const & | t2,
|  | typename genType::value_type const & | s
| ) |  |

Return a point from a hermite curve.

See also
  GLM_GTX_spline extension.